@@ -11,11 +11,11 @@ Dancer2::Plugin::PageHistory - store recent page history for user into session
 
 =head1 VERSION
 
-Version 0.208
+Version 0.209
 
 =cut
 
-our $VERSION = '0.208';
+our $VERSION = '0.209';
 
 use Dancer2::Core::Types qw/Bool HashRef Str/;
 use Dancer2::Plugin;
@@ -198,17 +198,9 @@ sub BUILD {
 sub add_to_history {
     my ( $plugin, @args ) = @_;
 
-    my %args = (
-        path         => $plugin->app->request->path,
-        query_string => $plugin->app->request->env->{QUERY_STRING},
-        @args,
-    );
-
-    $plugin->app->log( "debug", "adding page to history: ", \%args );
-
     my $history = $plugin->history;
 
-    $history->add( %args );
+    $history->add( request => $plugin->app->request, @args );
 
     $plugin->app->session->write(
         $plugin->history_name => unbless( $history->pages ) );
