@@ -6,6 +6,7 @@ use warnings;
 use lib 't/lib';
 use Test::More;
 use Dancer2::Plugin::PageHistory::PageSet;
+use File::Path;
 use HTTP::Cookies;
 use HTTP::Request::Common;
 use JSON qw//;
@@ -99,20 +100,8 @@ sub run_tests {
 
     $history = get_history('/one');
     cmp_ok( $history->latest_page->uri, "eq", "/one", "latest_page OK" );
+
+    File::Path::rmtree('sessions');
 }
 
 1;
-__END__
-if ( $engine =~ /^(Cookie|PSGI)$/ ) {
-  TODO: {
-        local $TODO = "Cookie and PSGI don't handle destroy correctly";
-        cmp_ok( keys %{ $history->pages }, '==', 1, "1 key in pages" );
-        cmp_ok( @{ $history->default },    '==', 1, "1 page type default" );
-        ok( !defined $history->previous_page, "previous_page undef" );
-    }
-}
-else {
-    cmp_ok( keys %{ $history->pages }, '==', 1, "1 key in pages" );
-    cmp_ok( @{ $history->default },    '==', 1, "1 page type default" );
-    ok( !defined $history->previous_page, "previous_page undef" );
-}
